@@ -1,9 +1,9 @@
-# © 2017 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
+"""Adds OCR layer to PDFs."""
+
+from __future__ import annotations
 
 from pluggy import HookimplMarker as _HookimplMarker
 
@@ -21,7 +21,6 @@ from ocrmypdf.exceptions import (
     InputFileError,
     MissingDependencyError,
     OutputFileAccessError,
-    PdfMergeFailedError,
     PriorOcrFoundError,
     SubprocessOutputError,
     TesseractConfigError,
