@@ -1,12 +1,13 @@
-# © 2020 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
+
+"""OCRmyPDF concurrency abstractions."""
+
+from __future__ import annotations
 
 import threading
 from abc import ABC, abstractmethod
-from typing import Callable, Iterable, Optional
+from typing import Callable, Iterable
 
 
 def _task_noop(*_args, **_kwargs):
@@ -14,6 +15,8 @@ def _task_noop(*_args, **_kwargs):
 
 
 class NullProgressBar:
+    """Progress bar API that takes no actions."""
+
     def __init__(self, **kwargs):
         pass
 
@@ -28,6 +31,8 @@ class NullProgressBar:
 
 
 class Executor(ABC):
+    """Abstract concurrent executor."""
+
     pool_lock = threading.Lock()
     pbar_class = NullProgressBar
 
@@ -41,10 +46,10 @@ class Executor(ABC):
         use_threads: bool,
         max_workers: int,
         tqdm_kwargs: dict,
-        worker_initializer: Optional[Callable] = None,
-        task: Optional[Callable] = None,
-        task_arguments: Optional[Iterable] = None,
-        task_finished: Optional[Callable] = None,
+        worker_initializer: Callable | None = None,
+        task: Callable | None = None,
+        task_arguments: Iterable | None = None,
+        task_finished: Callable | None = None,
     ) -> None:
         """
         Set up parallel execution and progress reporting.
