@@ -1,22 +1,19 @@
-# © 2018 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
+"""For grafting text-only PDF pages onto freeform PDF pages."""
+
+from __future__ import annotations
 
 import logging
-import uuid
 from contextlib import suppress
 from pathlib import Path
-from typing import Optional
 
 from pikepdf import (
     Dictionary,
     Name,
     Object,
     Operator,
-    Page,
     Pdf,
     PdfError,
     PdfMatrix,
@@ -81,6 +78,8 @@ def strip_invisible_text(pdf, page):
 
 
 class OcrGrafter:
+    """Manages grafting text-only PDFs onto regular PDFs."""
+
     def __init__(self, context):
         self.context = context
         self.path_base = context.origin
@@ -102,8 +101,8 @@ class OcrGrafter:
         self,
         *,
         pageno: int,
-        image: Optional[Path],
-        textpdf: Optional[Path],
+        image: Path | None,
+        textpdf: Path | None,
         autorotate_correction: int,
     ):
         if textpdf and not self.font:
@@ -236,6 +235,8 @@ class OcrGrafter:
     ):
         """Insert the text layer from text page 0 on to pdf_base at page_num"""
 
+        # pylint: disable=invalid-name
+
         log.debug("Grafting")
         if Path(textpdf).stat().st_size == 0:
             return
@@ -282,7 +283,7 @@ class OcrGrafter:
 
             base_resources = _ensure_dictionary(base_page, Name.Resources)
             base_xobjs = _ensure_dictionary(base_resources, Name.XObject)
-            text_xobj_name = Name('/' + str(uuid.uuid4()))
+            text_xobj_name = Name.random(prefix="OCR-")
             xobj = self.pdf_base.make_stream(pdf_text_contents)
             base_xobjs[text_xobj_name] = xobj
             xobj.Type = Name.XObject
