@@ -1,18 +1,19 @@
-# © 2020 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
+"""Logging support classes."""
+
+from __future__ import annotations
 
 import logging
-import sys
 from contextlib import suppress
 
 from tqdm import tqdm
 
 
 class PageNumberFilter(logging.Filter):
+    """Insert PDF page number that emitted log message to log record."""
+
     def filter(self, record):
         pageno = getattr(record, 'pageno', None)
         if isinstance(pageno, int):
