@@ -1,4 +1,5 @@
-# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-FileCopyrightText: 2019-2022 James R. Barlow
+# SPDX-FileCopyrightText: 2019 Martin Wind
 # SPDX-License-Identifier: MPL-2.0
 
 """Implements the concurrent and page synchronous parts of the pipeline."""
@@ -206,7 +207,7 @@ def exec_page_sync(page_context: PageContext) -> PageResult:
         filtered_image = page_context.plugin_manager.hook.filter_page_image(
             page=page_context, image_filename=visible_image_out
         )
-        if filtered_image:
+        if filtered_image is not None:  # None if no hook is present
             visible_image_out = filtered_image
         pdf_page_from_image_out = create_pdf_page_from_image(
             visible_image_out, page_context, orientation_correction
