@@ -1,12 +1,12 @@
-# © 2015-19 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
+"""Command line interface customization and validation."""
+
+from __future__ import annotations
 
 import argparse
-from typing import Any, Callable, Mapping, Optional, TypeVar
+from typing import Any, Callable, Mapping, TypeVar
 
 from ocrmypdf._version import PROGRAM_NAME as _PROGRAM_NAME
 from ocrmypdf._version import __version__ as _VERSION
@@ -14,9 +14,7 @@ from ocrmypdf._version import __version__ as _VERSION
 T = TypeVar('T', int, float)
 
 
-def numeric(
-    basetype: Callable[[Any], T], min_: Optional[T] = None, max_: Optional[T] = None
-):
+def numeric(basetype: Callable[[Any], T], min_: T | None = None, max_: T | None = None):
     """Validator for numeric params"""
     min_ = basetype(min_) if min_ is not None else None
     max_ = basetype(max_) if max_ is not None else None
@@ -42,7 +40,7 @@ def str_to_int(mapping: Mapping[str, int]):
         except KeyError:
             raise argparse.ArgumentTypeError(
                 f"{s!r} must be one of: {', '.join(mapping.keys())}"
-            )
+            ) from None
 
     return _str_to_int
 
@@ -51,12 +49,20 @@ class ArgumentParser(argparse.ArgumentParser):
     """Override parser's default behavior of calling sys.exit()
 
     https://stackoverflow.com/questions/5943249/python-argparse-and-controlling-overriding-the-exit-status-code
+
+    OCRmyPDF began as a CLI but eventually acquired an API. The API works inside out,
+    by synthesizing a command line argument. So we subclass the standard parser with
+    one that doesn't call sys.exit(). Obviously this is not the ideal way to do things
+    but it works for us.
     """
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._api_mode = False
 
+    def enable_api_mode(self):
+        self._api_mode = True
+
     def error(self, message):
         if not self._api_mode:
             super().error(message)
@@ -65,6 +71,8 @@ class ArgumentParser(argparse.ArgumentParser):
 
 
 class LanguageSetAction(argparse.Action):
+    """Manages a list of languages."""
+
     def __init__(self, option_strings, dest, default=None, **kwargs):
         if default is None:
             default = set()
@@ -228,7 +236,13 @@ Online documentation is located at:
         help=argparse.SUPPRESS,
     )
     jobcontrol.add_argument(
-        '--use-threads', action='store_true', help=argparse.SUPPRESS
+        '--use-threads', action='store_true', default=True, help=argparse.SUPPRESS
+    )
+    jobcontrol.add_argument(
+        '--no-use-threads',
+        action='store_false',
+        dest='use_threads',
+        help=argparse.SUPPRESS,
     )
 
     metadata = parser.add_argument_group(
@@ -335,72 +349,6 @@ Online documentation is located at:
         "but include skipped pages in final output",
     )
 
-    optimizing = parser.add_argument_group(
-        "Optimization options", "Control how the PDF is optimized after OCR"
-    )
-    optimizing.add_argument(
-        '-O',
-        '--optimize',
-        type=int,
-        choices=range(0, 4),
-        default=1,
-        help=(
-            "Control how PDF is optimized after processing:"
-            "0 - do not optimize; "
-            "1 - do safe, lossless optimizations (default); "
-            "2 - do lossy JPEG and JPEG2000 optimizations; "
-            "3 - do more aggressive lossy JPEG and JPEG2000 optimizations. "
-            "To enable lossy JBIG2, see --jbig2-lossy."
-        ),
-    )
-    optimizing.add_argument(
-        '--jpeg-quality',
-        type=numeric(int, 0, 100),
-        default=0,
-        metavar='Q',
-        help=(
-            "Adjust JPEG quality level for JPEG optimization. "
-            "100 is best quality and largest output size; "
-            "1 is lowest quality and smallest output; "
-            "0 uses the default."
-        ),
-    )
-    optimizing.add_argument(
-        '--jpg-quality',
-        type=numeric(int, 0, 100),
-        default=0,
-        metavar='Q',
-        dest='jpeg_quality',
-        help=argparse.SUPPRESS,  # Alias for --jpeg-quality
-    )
-    optimizing.add_argument(
-        '--png-quality',
-        type=numeric(int, 0, 100),
-        default=0,
-        metavar='Q',
-        help=(
-            "Adjust PNG quality level to use when quantizing PNGs. "
-            "Values have same meaning as with --jpeg-quality"
-        ),
-    )
-    optimizing.add_argument(
-        '--jbig2-lossy',
-        action='store_true',
-        help=(
-            "Enable JBIG2 lossy mode (better compression, not suitable for some "
-            "use cases - see documentation). Only takes effect if --optimize 1 or "
-            "higher is also enabled."
-        ),
-    )
-    optimizing.add_argument(
-        '--jbig2-page-group-size',
-        type=numeric(int, 1, 10000),
-        default=0,
-        metavar='N',
-        # Adjust number of pages to consider at once for JBIG2 compression
-        help=argparse.SUPPRESS,
-    )
-
     advanced = parser.add_argument_group(
         "Advanced", "Advanced options to control OCRmyPDF"
     )
