@@ -1,9 +1,10 @@
-# © 2018 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
+"""Post-processing image optimization of OCR PDFs."""
+
+
+from __future__ import annotations
 
 import logging
 import sys
@@ -12,18 +13,7 @@ import threading
 from collections import defaultdict
 from os import fspath
 from pathlib import Path
-from typing import (
-    Callable,
-    Dict,
-    Iterator,
-    List,
-    MutableSet,
-    NamedTuple,
-    NewType,
-    Optional,
-    Sequence,
-    Tuple,
-)
+from typing import Callable, Iterator, MutableSet, NamedTuple, NewType, Sequence
 from zlib import compress
 
 import img2pdf
@@ -55,7 +45,9 @@ DEFAULT_PNG_QUALITY = 70
 Xref = NewType('Xref', int)
 
 
-class XrefExt(NamedTuple):  # pylint: disable=inherit-non-class
+class XrefExt(NamedTuple):
+    """A PDF xref and image extension pair."""
+
     xref: Xref
     ext: str
 
@@ -74,7 +66,7 @@ def jpg_name(root: Path, xref: Xref) -> Path:
 
 def extract_image_filter(
     pike: Pdf, root: Path, image: Stream, xref: Xref
-) -> Optional[Tuple[PdfImage, Tuple[Name, Object]]]:
+) -> tuple[PdfImage, tuple[Name, Object]] | None:
     del pike  # unused args
     del root
 
@@ -131,7 +123,7 @@ def extract_image_filter(
 
 def extract_image_jbig2(
     *, pike: Pdf, root: Path, image: Stream, xref: Xref, options
-) -> Optional[XrefExt]:
+) -> XrefExt | None:
     del options  # unused arg
 
     result = extract_image_filter(pike, root, image, xref)
@@ -172,7 +164,7 @@ def extract_image_jbig2(
 
 def extract_image_generic(
     *, pike: Pdf, root: Path, image: Stream, xref: Xref, options
-) -> Optional[XrefExt]:
+) -> XrefExt | None:
     result = extract_image_filter(pike, root, image, xref)
     if result is None:
         return None
@@ -236,8 +228,8 @@ def extract_images(
     pike: Pdf,
     root: Path,
     options,
-    extract_fn: Callable[..., Optional[XrefExt]],
-) -> Iterator[Tuple[int, XrefExt]]:
+    extract_fn: Callable[..., XrefExt | None],
+) -> Iterator[tuple[int, XrefExt]]:
     """Extract image using extract_fn
 
     Enumerate images on each page, lookup their xref/ID number in the PDF.
@@ -266,7 +258,7 @@ def extract_images(
             if image.objgen[1] != 0:
                 continue  # Ignore images in an incremental PDF
             xref = Xref(image.objgen[0])
-            if hasattr(image, 'SMask'):
+            if Name.SMask in image:
                 # Ignore soft masks
                 smask_xref = Xref(image.SMask.objgen[0])
                 exclude_xrefs.add(smask_xref)
@@ -296,7 +288,7 @@ def extract_images(
 
 def extract_images_generic(
     pike: Pdf, root: Path, options
-) -> Tuple[List[Xref], List[Xref]]:
+) -> tuple[list[Xref], list[Xref]]:
     """Extract any >=2bpp image we think we can improve"""
 
     jpegs = []
@@ -311,7 +303,7 @@ def extract_images_generic(
     return jpegs, pngs
 
 
-def extract_images_jbig2(pike: Pdf, root: Path, options) -> Dict[int, List[XrefExt]]:
+def extract_images_jbig2(pike: Pdf, root: Path, options) -> dict[int, list[XrefExt]]:
     """Extract any bitonal image that we think we can improve as JBIG2"""
 
     jbig2_groups = defaultdict(list)
@@ -324,11 +316,11 @@ def extract_images_jbig2(pike: Pdf, root: Path, options) -> Dict[int, List[XrefE
 
 
 def _produce_jbig2_images(
-    jbig2_groups: Dict[int, List[XrefExt]], root: Path, options, executor: Executor
+    jbig2_groups: dict[int, list[XrefExt]], root: Path, options, executor: Executor
 ) -> None:
     """Produce JBIG2 images from their groups"""
 
-    def jbig2_group_args(root: Path, groups: Dict[int, List[XrefExt]]):
+    def jbig2_group_args(root: Path, groups: dict[int, list[XrefExt]]):
         for group, xref_exts in groups.items():
             prefix = f'group{group:08d}'
             yield (
@@ -337,7 +329,7 @@ def _produce_jbig2_images(
                 prefix,  # =out_prefix
             )
 
-    def jbig2_single_args(root, groups: Dict[int, List[XrefExt]]):
+    def jbig2_single_args(root, groups: dict[int, list[XrefExt]]):
         for group, xref_exts in groups.items():
             prefix = f'group{group:08d}'
             # Second loop is to ensure multiple images per page are unpacked
@@ -372,7 +364,7 @@ def _produce_jbig2_images(
 
 def convert_to_jbig2(
     pike: Pdf,
-    jbig2_groups: Dict[int, List[XrefExt]],
+    jbig2_groups: dict[int, list[XrefExt]],
     root: Path,
     options,
     executor: Executor,
@@ -389,7 +381,7 @@ def convert_to_jbig2(
     When the JBIG2 symbolic coder is not used, each JBIG2 stands on its own
     and needs no dictionary. Currently this must be lossless JBIG2.
     """
-    jbig2_globals_dict: Optional[Dictionary]
+    jbig2_globals_dict: Dictionary | None
 
     _produce_jbig2_images(jbig2_groups, root, options, executor)
 
@@ -415,7 +407,7 @@ def convert_to_jbig2(
             )
 
 
-def _optimize_jpeg(args: Tuple[Xref, Path, Path, int]) -> Tuple[Xref, Optional[Path]]:
+def _optimize_jpeg(args: tuple[Xref, Path, Path, int]) -> tuple[Xref, Path | None]:
     xref, in_jpg, opt_jpg, jpeg_quality = args
 
     with Image.open(in_jpg) as im:
@@ -431,13 +423,13 @@ def _optimize_jpeg(args: Tuple[Xref, Path, Path, int]) -> Tuple[Xref, Optional[P
 def transcode_jpegs(
     pike: Pdf, jpegs: Sequence[Xref], root: Path, options, executor: Executor
 ) -> None:
-    def jpeg_args() -> Iterator[Tuple[Xref, Path, Path, int]]:
+    def jpeg_args() -> Iterator[tuple[Xref, Path, Path, int]]:
         for xref in jpegs:
             in_jpg = jpg_name(root, xref)
             opt_jpg = in_jpg.with_suffix('.opt.jpg')
             yield xref, in_jpg, opt_jpg, options.jpeg_quality
 
-    def finish_jpeg(result: Tuple[Xref, Optional[Path]], pbar):
+    def finish_jpeg(result: tuple[Xref, Path | None], pbar):
         xref, opt_jpg = result
         if opt_jpg:
             compdata = opt_jpg.read_bytes()  # JPEG can inserted into PDF as is
@@ -462,11 +454,11 @@ def transcode_jpegs(
 
 def _find_deflatable_jpeg(
     *, pike: Pdf, root: Path, image: Stream, xref: Xref, options
-) -> Optional[XrefExt]:
+) -> XrefExt | None:
     result = extract_image_filter(pike, root, image, xref)
     if result is None:
         return None
-    pim, filtdp = result
+    _pim, filtdp = result
 
     if filtdp[0] == Name.DCTDecode and not filtdp[1] and options.optimize >= 1:
         return XrefExt(xref, '.memory')
@@ -474,7 +466,7 @@ def _find_deflatable_jpeg(
     return None
 
 
-def _deflate_jpeg(args: Tuple[Pdf, threading.Lock, Xref, int]) -> Tuple[Xref, bytes]:
+def _deflate_jpeg(args: tuple[Pdf, threading.Lock, Xref, int]) -> tuple[Xref, bytes]:
     pike, lock, xref, complevel = args
     with lock:
         xobj = pike.get_object(xref, 0)
@@ -621,11 +613,11 @@ def optimize(
     context,
     save_settings,
     executor: Executor = DEFAULT_EXECUTOR,
-) -> None:
+) -> Path:
     options = context.options
     if options.optimize == 0:
         safe_symlink(input_file, output_file)
-        return
+        return output_file
 
     if options.jpeg_quality == 0:
         options.jpeg_quality = DEFAULT_JPEG_QUALITY if options.optimize < 3 else 40
@@ -660,9 +652,7 @@ def optimize(
             f"Output file not created after optimizing. We probably ran "
             f"out of disk space in the temporary folder: {tempfile.gettempdir()}."
         )
-    ratio = input_size / output_size
     savings = 1 - output_size / input_size
-    log.info(f"Optimize ratio: {ratio:.2f} savings: {(savings):.1%}")
 
     if savings < 0:
         log.info(
@@ -676,6 +666,8 @@ def optimize(
     else:
         safe_symlink(target_file, output_file)
 
+    return output_file
+
 
 def main(infile, outfile, level, jobs=1):
     from shutil import copy  # pylint: disable=import-outside-toplevel
@@ -707,9 +699,9 @@ def main(infile, outfile, level, jobs=1):
         jb2lossy=False,
     )
 
-    with TemporaryDirectory() as td:
-        context = PdfContext(options, td, infile, None, None)
-        tmpout = Path(td) / 'out.pdf'
+    with TemporaryDirectory() as tmpdir:
+        context = PdfContext(options, tmpdir, infile, None, None)
+        tmpout = Path(tmpdir) / 'out.pdf'
         optimize(
             infile,
             tmpout,
