@@ -1,22 +1,20 @@
-# © 2020 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
 """
 Utilities for PDF/A production and confirmation with Ghostspcript.
 """
 
+from __future__ import annotations
+
 import base64
 from pathlib import Path
-from typing import Dict, Iterator, Union
+from typing import Iterator
 
 try:
-    from importlib_resources import files as package_files
-except ImportError:
     from importlib.resources import files as package_files
+except ImportError:
+    from importlib_resources import files as package_files  # type: ignore
 
 import pikepdf
 
@@ -25,7 +23,7 @@ SRGB_ICC_PROFILE_NAME = 'sRGB.icc'
 
 def _postscript_objdef(
     alias: str,
-    dictionary: Dict[str, str],
+    dictionary: dict[str, str],
     *,
     stream_name: str = None,
     stream_data: bytes = None,
@@ -97,7 +95,8 @@ def generate_pdfa_ps(target_filename: Path, icc: str = 'sRGB'):
         target_filename: filename to save
         icc: ICC identifier such as 'sRGB'
     References:
-        Adobe PDFMARK Reference: https://www.adobe.com/content/dam/acom/en/devnet/acrobat/pdfs/pdfmark_reference.pdf
+        Adobe PDFMARK Reference:
+        https://www.adobe.com/content/dam/acom/en/devnet/acrobat/pdfs/pdfmark_reference.pdf
     """
     if icc != 'sRGB':
         raise NotImplementedError("Only supporting sRGB")
@@ -105,11 +104,11 @@ def generate_pdfa_ps(target_filename: Path, icc: str = 'sRGB'):
     bytes_icc_profile = (
         package_files('ocrmypdf.data') / SRGB_ICC_PROFILE_NAME
     ).read_bytes()
-    ps = '\n'.join(_make_postscript(icc, bytes_icc_profile, 3))
+    postscript = '\n'.join(_make_postscript(icc, bytes_icc_profile, 3))
 
     # We should have encoded everything to pure ASCII by this point, and
     # to be safe, only allow ASCII in PostScript
-    Path(target_filename).write_text(ps, encoding='ascii')
+    Path(target_filename).write_text(postscript, encoding='ascii')
     return target_filename
 
 
@@ -130,7 +129,7 @@ def file_claims_pdfa(filename: Path):
             }
         valid_part_conforms = {'1A', '1B', '2A', '2B', '2U', '3A', '3B', '3U'}
         conformance = f'PDF/A-{pdfmeta.pdfa_status}'
-        pdfa_dict: Dict[str, Union[str, bool]] = {}
+        pdfa_dict: dict[str, str | bool] = {}
         if pdfmeta.pdfa_status in valid_part_conforms:
             pdfa_dict['pass'] = True
             pdfa_dict['output'] = 'pdfa'
