@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
-# © 2015 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
+"""Extract information about the content of a PDF."""
+
+from __future__ import annotations
 
 import atexit
 import logging
@@ -12,23 +12,12 @@ import re
 from collections import defaultdict
 from contextlib import ExitStack
 from decimal import Decimal
-from enum import Enum
+from enum import Enum, auto
 from functools import partial
 from math import hypot, inf, isclose
 from os import PathLike
 from pathlib import Path
-from typing import (
-    Container,
-    Dict,
-    Iterator,
-    List,
-    Mapping,
-    NamedTuple,
-    Optional,
-    Sequence,
-    Tuple,
-    Union,
-)
+from typing import Container, Iterable, Iterator, Mapping, NamedTuple, Sequence, Tuple
 from warnings import warn
 
 from pikepdf import (
@@ -37,6 +26,7 @@ from pikepdf import (
     PdfImage,
     PdfInlineImage,
     PdfMatrix,
+    UnsupportedImageTypeError,
     parse_content_stream,
 )
 
@@ -47,13 +37,41 @@ from ocrmypdf.pdfinfo.layout import get_page_analysis, get_text_boxes
 
 logger = logging.getLogger()
 
-Colorspace = Enum('Colorspace', 'gray rgb cmyk lab icc index sep devn pattern jpeg2000')
 
-Encoding = Enum(
-    'Encoding', 'ccitt jpeg jpeg2000 jbig2 asciihex ascii85 lzw flate runlength'
-)
+class Colorspace(Enum):
+    """Description of common image colorspaces in a PDF."""
 
-FRIENDLY_COLORSPACE: Dict[str, Colorspace] = {
+    # pylint: disable=invalid-name
+    gray = auto()
+    rgb = auto()
+    cmyk = auto()
+    lab = auto()
+    icc = auto()
+    index = auto()
+    sep = auto()
+    devn = auto()
+    pattern = auto()
+    jpeg2000 = auto()
+
+
+class Encoding(Enum):
+    """Description of common image encodings in a PDF."""
+
+    # pylint: disable=invalid-name
+    ccitt = auto()
+    jpeg = auto()
+    jpeg2000 = auto()
+    jbig2 = auto()
+    asciihex = auto()
+    ascii85 = auto()
+    lzw = auto()
+    flate = auto()
+    runlength = auto()
+
+
+FloatRect = Tuple[float, float, float, float]
+
+FRIENDLY_COLORSPACE: dict[str, Colorspace] = {
     '/DeviceGray': Colorspace.gray,
     '/CalGray': Colorspace.gray,
     '/DeviceRGB': Colorspace.rgb,
@@ -71,7 +89,7 @@ FRIENDLY_COLORSPACE: Dict[str, Colorspace] = {
     '/I': Colorspace.index,
 }
 
-FRIENDLY_ENCODING: Dict[str, Encoding] = {
+FRIENDLY_ENCODING: dict[str, Encoding] = {
     '/CCITTFaxDecode': Encoding.ccitt,
     '/DCTDecode': Encoding.jpeg,
     '/JPXDecode': Encoding.jpeg2000,
@@ -85,7 +103,7 @@ FRIENDLY_ENCODING: Dict[str, Encoding] = {
     '/RL': Encoding.runlength,
 }
 
-FRIENDLY_COMP: Dict[Colorspace, int] = {
+FRIENDLY_COMP: dict[Colorspace, int] = {
     Colorspace.gray: 1,
     Colorspace.rgb: 3,
     Colorspace.cmyk: 4,
@@ -104,37 +122,45 @@ def _is_unit_square(shorthand):
 
 
 class XobjectSettings(NamedTuple):
+    """Info about an XObject found in a PDF."""
+
     name: str
-    shorthand: Tuple[float, float, float, float, float, float]
+    shorthand: tuple[float, float, float, float, float, float]
     stack_depth: int
 
 
 class InlineSettings(NamedTuple):
+    """Info about an inline image found in a PDF."""
+
     iimage: PdfInlineImage
-    shorthand: Tuple[float, float, float, float, float, float]
+    shorthand: tuple[float, float, float, float, float, float]
     stack_depth: int
 
 
 class ContentsInfo(NamedTuple):
-    xobject_settings: List[XobjectSettings]
-    inline_images: List[InlineSettings]
+    """Info about various objects found in a PDF."""
+
+    xobject_settings: list[XobjectSettings]
+    inline_images: list[InlineSettings]
     found_vector: bool
     found_text: bool
-    name_index: Mapping[str, List[XobjectSettings]]
+    name_index: Mapping[str, list[XobjectSettings]]
 
 
 class TextboxInfo(NamedTuple):
-    bbox: Tuple[float, float, float, float]
+    """Info about a text box found in a PDF."""
+
+    bbox: tuple[float, float, float, float]
     is_visible: bool
     is_corrupt: bool
 
 
 class VectorMarker:
-    pass
+    """Sentinel indicating vector drawing operations were found on a page."""
 
 
 class TextMarker:
-    pass
+    """Sentinel indicating text drawing operations were found on a page."""
 
 
 def _normalize_stack(graphobjs):
@@ -177,8 +203,8 @@ def _interpret_contents(contentstream: Object, initial_shorthand=UNIT_SQUARE):
 
     stack = []
     ctm = PdfMatrix(initial_shorthand)
-    xobject_settings: List[XobjectSettings] = []
-    inline_images: List[InlineSettings] = []
+    xobject_settings: list[XobjectSettings] = []
+    inline_images: list[InlineSettings] = []
     name_index = defaultdict(lambda: [])
     found_vector = False
     found_text = False
@@ -196,7 +222,7 @@ def _interpret_contents(contentstream: Object, initial_shorthand=UNIT_SQUARE):
             if len(stack) > 32:  # See docstring
                 if len(stack) > 128:
                     raise RuntimeError(
-                        "PDF graphics stack overflowed hard limit, operator %i" % n
+                        f"PDF graphics stack overflowed hard limit at operator {n}"
                     )
                 warn("PDF graphics stack overflowed spec limit")
         elif operator == 'Q':
@@ -282,7 +308,7 @@ def _get_dpi(ctm_shorthand, image_size) -> Resolution:
 
     """
 
-    a, b, c, d, _, _ = ctm_shorthand
+    a, b, c, d, _, _ = ctm_shorthand  # pylint: disable=invalid-name
 
     # Calculate the width and height of the image in PDF units
     image_drawn = hypot(a, b), hypot(c, d)
@@ -298,23 +324,25 @@ def _get_dpi(ctm_shorthand, image_size) -> Resolution:
 
 
 class ImageInfo:
+    """Information about an image found in a PDF."""
+
     DPI_PREC = Decimal('1.000')
 
-    _comp: Optional[int]
+    _comp: int | None
     _name: str
 
     def __init__(
         self,
         *,
         name='',
-        pdfimage: Optional[Object] = None,
-        inline: Optional[PdfInlineImage] = None,
+        pdfimage: Object | None = None,
+        inline: PdfInlineImage | None = None,
         shorthand=None,
     ):
         self._name = str(name)
         self._shorthand = shorthand
 
-        pim: Union[PdfInlineImage, PdfImage]
+        pim: PdfInlineImage | PdfImage
 
         if inline is not None:
             self._origin = 'inline'
@@ -350,13 +378,20 @@ class ImageInfo:
 
         if self._color == Colorspace.icc:
             # Check the ICC profile to determine actual colorspace
-            pim_icc = pim.icc
-            if pim_icc.profile.xcolor_space == 'GRAY':
-                self._comp = 1
-            elif pim_icc.profile.xcolor_space == 'CMYK':
-                self._comp = 4
-            else:
-                self._comp = 3
+            try:
+                pim_icc = pim.icc
+                if pim_icc.profile.xcolor_space == 'GRAY':
+                    self._comp = 1
+                elif pim_icc.profile.xcolor_space == 'CMYK':
+                    self._comp = 4
+                else:
+                    self._comp = 3
+            except (AttributeError, UnsupportedImageTypeError) as ex:
+                self._comp = None
+                logger.warning(
+                    f"An image with a corrupt or unreadable ICC profile was found. "
+                    f"The output PDF may not match the input PDF visually: {ex}. {self}"
+                )
         else:
             if isinstance(self._color, Colorspace):
                 self._comp = FRIENDLY_COMP.get(self._color)
@@ -409,15 +444,10 @@ class ImageInfo:
         return _get_dpi(self._shorthand, (self._width, self._height))
 
     def __repr__(self):
-        class_locals = {
-            attr: getattr(self, attr, None)
-            for attr in dir(self)
-            if not attr.startswith('_')
-        }
         return (
-            "<ImageInfo '{name}' {type_} {width}x{height} {color} "
-            "{comp} {bpc} {enc} {dpi}>"
-        ).format(**class_locals)
+            f"<ImageInfo '{self.name}' {self.type_} {self.width}x{self.height} "
+            f"{self.color} {self.comp} {self.bpc} {self.enc} {self.dpi}>"
+        )
 
 
 def _find_inline_images(contentsinfo: ContentsInfo) -> Iterator[ImageInfo]:
@@ -425,11 +455,11 @@ def _find_inline_images(contentsinfo: ContentsInfo) -> Iterator[ImageInfo]:
 
     for n, inline in enumerate(contentsinfo.inline_images):
         yield ImageInfo(
-            name='inline-%02d' % n, shorthand=inline.shorthand, inline=inline.iimage
+            name=f'inline-{n:02d}', shorthand=inline.shorthand, inline=inline.iimage
         )
 
 
-def _image_xobjects(container) -> Iterator[Tuple[Object, str]]:
+def _image_xobjects(container) -> Iterator[tuple[Object, str]]:
     """Search for all XObject-based images in the container
 
     Usually the container is a page, but it could also be a Form XObject
@@ -517,7 +547,7 @@ def _find_form_xobject_images(pdf: Pdf, container: Object, contentsinfo: Content
 
 def _process_content_streams(
     *, pdf: Pdf, container: Object, shorthand=None
-) -> Iterator[Union[VectorMarker, TextMarker, ImageInfo]]:
+) -> Iterator[VectorMarker | TextMarker | ImageInfo]:
     """Find all individual instances of images drawn in the container
 
     Usually the container is a page, but it may also be a Form XObject.
@@ -566,10 +596,10 @@ def _process_content_streams(
     yield from _find_form_xobject_images(pdf, container, contentsinfo)
 
 
-def _page_has_text(text_blocks, page_width, page_height) -> bool:
+def _page_has_text(text_blocks: Iterable[FloatRect], page_width, page_height) -> bool:
     """Smarter text detection that ignores text in margins"""
 
-    pw, ph = float(page_width), float(page_height)
+    pw, ph = float(page_width), float(page_height)  # pylint: disable=invalid-name
 
     margin_ratio = 0.125
     interior_bbox = (
@@ -579,7 +609,7 @@ def _page_has_text(text_blocks, page_width, page_height) -> bool:
         margin_ratio * ph,  # bottom  (first quadrant: bottom < top)
     )
 
-    def rects_intersect(a, b) -> bool:
+    def rects_intersect(a: FloatRect, b: FloatRect) -> bool:
         """
         Where (a,b) are 4-tuple rects (left-0, top-1, right-2, bottom-3)
         https://stackoverflow.com/questions/306316/determine-if-two-rectangles-overlap-each-other
@@ -601,19 +631,19 @@ def simplify_textboxes(miner, textbox_getter) -> Iterator[TextboxInfo]:
     We do this to save memory and ensure that our objects are pickleable.
     """
     for box in textbox_getter(miner):
-        first_line = box._objs[0]
-        first_char = first_line._objs[0]
+        first_line = box._objs[0]  # pylint: disable=protected-access
+        first_char = first_line._objs[0]  # pylint: disable=protected-access
 
         visible = first_char.rendermode != 3
         corrupt = first_char.get_text() == '\ufffd'
         yield TextboxInfo(box.bbox, visible, corrupt)
 
 
-worker_pdf = None
+worker_pdf = None  # pylint: disable=invalid-name
 
 
 def _pdf_pageinfo_sync_init(pdf: Pdf, infile: Path, pdfminer_loglevel):
-    global worker_pdf  # pylint: disable=global-statement
+    global worker_pdf  # pylint: disable=global-statement,invalid-name
     pikepdf_enable_mmap()
 
     logging.getLogger('pdfminer').setLevel(pdfminer_loglevel)
@@ -647,8 +677,8 @@ def _pdf_pageinfo_concurrent(
     max_workers,
     check_pages,
     detailed_analysis=False,
-) -> List[Optional['PageInfo']]:
-    pages = [None] * len(pdf.pages)
+) -> Sequence[PageInfo | None]:
+    pages: Sequence[PageInfo | None] = [None] * len(pdf.pages)
 
     def update_pageinfo(result, pbar):
         page = result
@@ -698,9 +728,11 @@ def _pdf_pageinfo_concurrent(
 
 
 class PageInfo:
-    _has_text: Optional[bool]
-    _has_vector: Optional[bool]
-    _images: List[ImageInfo]
+    """Information about type of contents on each page in a PDF."""
+
+    _has_text: bool | None
+    _has_vector: bool | None
+    _images: list[ImageInfo]
 
     def __init__(
         self,
@@ -759,15 +791,15 @@ class PageInfo:
             self._has_vector = False
             self._has_text = False
             self._images = []
-            for ci in _process_content_streams(
+            for info in _process_content_streams(
                 pdf=pdf, container=page, shorthand=userunit_shorthand
             ):
-                if isinstance(ci, VectorMarker):
+                if isinstance(info, VectorMarker):
                     self._has_vector = True
-                elif isinstance(ci, TextMarker):
+                elif isinstance(info, TextMarker):
                     self._has_text = True
-                elif isinstance(ci, ImageInfo):
-                    self._images.append(ci)
+                elif isinstance(info, ImageInfo):
+                    self._images.append(info)
                 else:
                     raise NotImplementedError()
         else:
@@ -833,9 +865,7 @@ class PageInfo:
     def images(self):
         return self._images
 
-    def get_textareas(
-        self, visible: Optional[bool] = None, corrupt: Optional[bool] = None
-    ):
+    def get_textareas(self, visible: bool | None = None, corrupt: bool | None = None):
         def predicate(obj, want_visible, want_corrupt):
             result = True
             if want_visible is not None:
@@ -919,24 +949,24 @@ class PdfInfo:
                     self._has_acroform = True
 
     @property
-    def pages(self) -> Sequence[Optional[PageInfo]]:
+    def pages(self) -> Sequence[PageInfo | None]:
         return self._pages
 
     @property
     def min_version(self) -> str:
         # The minimum PDF is the maximum version that any particular page needs
-        return max(page.min_version for page in self.pages)
+        return max(page.min_version for page in self.pages if page)
 
     @property
     def has_userunit(self) -> bool:
-        return any(page.userunit != 1.0 for page in self.pages)
+        return any(page.userunit != 1.0 for page in self.pages if page)
 
     @property
     def has_acroform(self) -> bool:
         return self._has_acroform
 
     @property
-    def filename(self) -> Union[str, Path]:
+    def filename(self) -> str | Path:
         if not isinstance(self._infile, (str, Path)):
             raise NotImplementedError("can't get filename from stream")
         return self._infile
