@@ -7,16 +7,15 @@ import os
 import shutil
 from math import isclose
 from pathlib import Path
-from subprocess import PIPE, run
+from subprocess import run
 from unittest.mock import patch
 
 import pikepdf
-import PIL
 import pytest
 from PIL import Image
 
 import ocrmypdf
-from ocrmypdf._exec import ghostscript, tesseract
+from ocrmypdf._exec import tesseract
 from ocrmypdf.exceptions import ExitCode, MissingDependencyError
 from ocrmypdf.pdfa import file_claims_pdfa
 from ocrmypdf.pdfinfo import Colorspace, Encoding, PdfInfo
@@ -153,9 +152,9 @@ def test_skip_big(resources, outpdf):
 
 @pytest.mark.parametrize('renderer', RENDERERS)
 @pytest.mark.parametrize('output_type', ['pdf', 'pdfa'])
-def test_maximum_options(renderer, output_type, resources, outpdf):
+def test_maximum_options(renderer, output_type, multipage, outpdf):
     check_ocrmypdf(
-        resources / 'multipage.pdf',
+        multipage,
         outpdf,
         '-d',
         '-ci' if have_unpaper() else None,
@@ -179,7 +178,8 @@ def test_maximum_options(renderer, output_type, resources, outpdf):
 
 
 @pytest.mark.skipif(
-    tesseract.version() >= '5', reason="tess 5 tries harder to find its files"
+    tesseract.TesseractVersion(tesseract.version()) >= tesseract.TesseractVersion('5'),
+    reason="tess 5 tries harder to find its files",
 )
 def test_tesseract_missing_tessdata(monkeypatch, resources, no_outpdf, tmpdir):
     monkeypatch.setenv("TESSDATA_PREFIX", os.fspath(tmpdir))
@@ -292,12 +292,6 @@ def test_input_file_not_a_pdf(caplog, no_outpdf):
         assert input_file in caplog.text
 
 
-def test_encrypted(resources, caplog, no_outpdf):
-    result = run_ocrmypdf_api(resources / 'skew-encrypted.pdf', no_outpdf)
-    assert result == ExitCode.encrypted_pdf
-    assert 'encryption must be removed' in caplog.text
-
-
 @pytest.mark.parametrize('renderer', RENDERERS)
 def test_pagesegmode(renderer, resources, outpdf):
     check_ocrmypdf(
@@ -398,14 +392,27 @@ def test_tesseract_image_too_big(renderer, resources, outpdf):
     )
 
 
-def test_algo4(resources, outpdf):
-    p = run_ocrmypdf(
-        resources / 'encrypted_algo4.pdf',
+@pytest.mark.parametrize('encryption_level', [2, 3, 4, 6])
+def test_encrypted(resources, outpdf, encryption_level, caplog):
+    encryption = pikepdf.models.encryption.Encryption(
+        owner='ocrmypdf',
+        user='ocrmypdf',
+        R=encryption_level,
+        aes=(encryption_level >= 4),
+        metadata=(encryption_level == 6),
+    )
+
+    with pikepdf.open(resources / 'jbig2.pdf') as pdf:
+        pdf.save(outpdf, encryption=encryption)
+
+    exitcode = run_ocrmypdf_api(
+        outpdf,
         outpdf,
         '--plugin',
         'tests/plugins/tesseract_noop.py',
     )
-    assert p.returncode == ExitCode.encrypted_pdf
+    assert exitcode == ExitCode.encrypted_pdf
+    assert 'encryption must be removed' in caplog.text
 
 
 def test_jbig2_passthrough(resources, outpdf):
@@ -539,7 +546,6 @@ def test_tesseract_config_invalid(renderer, resources, invalid_tess_config, outp
     assert p.returncode == ExitCode.invalid_config
 
 
-@pytest.mark.skipif(not tesseract.has_user_words(), reason='not functional until 4.1.0')
 def test_user_words_ocr(resources, outdir):
     # Does not actually test if --user-words causes output to differ
     word_list = outdir / 'wordlist.txt'
@@ -716,11 +722,9 @@ def test_compression_changed(ocrmypdf_exec, resources, image, compression, outpd
     if compression == "jpeg":
         assert pdfimage.enc == Encoding.jpeg
     else:
-        if ghostscript.jpeg_passthrough_available():
-            # Ghostscript 9.23 adds JPEG passthrough, which allows a JPEG to be
-            # copied without transcoding - so report
-            if image.endswith('jpg'):
-                assert pdfimage.enc == Encoding.jpeg
+        if image.endswith('jpg'):
+            # Ghostscript JPEG passthrough - no issue
+            assert pdfimage.enc == Encoding.jpeg
         else:
             assert pdfimage.enc not in (Encoding.jpeg, Encoding.jpeg2000)
 
@@ -774,9 +778,6 @@ def test_sidecar_nonempty(resources, outpdf):
 
 @pytest.mark.parametrize('pdfa_level', ['1', '2', '3'])
 def test_pdfa_n(pdfa_level, resources, outpdf):
-    if pdfa_level == '3' and ghostscript.version() < '9.19':
-        pytest.xfail(reason='Ghostscript >= 9.19 required')
-
     check_ocrmypdf(
         resources / 'ccitt.pdf',
         outpdf,
