@@ -1,9 +1,7 @@
-# © 2018 James R. Barlow: github.com/jbarlow83
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
+from __future__ import annotations
 
 import operator
 from io import BytesIO
@@ -25,6 +23,12 @@ from .conftest import check_ocrmypdf, run_ocrmypdf
 
 # pylintx: disable=unused-variable
 
+# Remove this workaround when we require Pillow >= 10
+try:
+    Transpose = Image.Transpose  # type: ignore
+except AttributeError:
+    # Pillow 9 shim
+    Transpose = Image  # type: ignore
 
 RENDERERS = ['hocr', 'sandwich']
 
@@ -222,7 +226,7 @@ def test_rotate_page_level(image_angle, page_angle, resources, outdir):
         with Image.open(fspath(resources / 'typewriter.png')) as im:
             if image_angle != 0:
                 ccw_angle = -image_angle % 360
-                im = im.transpose(getattr(Image, f'ROTATE_{ccw_angle}'))
+                im = im.transpose(getattr(Transpose, f'ROTATE_{ccw_angle}'))
             im.save(memimg, format='PNG')
         memimg.seek(0)
         mempdf = BytesIO()
@@ -272,7 +276,8 @@ def test_rasterize_rotates(resources, tmp_path):
         rotation=90,
         filter_vector=False,
     )
-    assert Image.open(img).size == (123, 151), "Image not rotated"
+    with Image.open(img) as im:
+        assert im.size == (83, 200), "Image not rotated"
 
     img = tmp_path / 'img180.png'
     pm.hook.rasterize_pdf_page(
@@ -285,7 +290,7 @@ def test_rasterize_rotates(resources, tmp_path):
         rotation=180,
         filter_vector=False,
     )
-    assert Image.open(img).size == (151, 123), "Image not rotated"
+    assert Image.open(img).size == (200, 83), "Image not rotated"
 
 
 def test_simulated_scan(outdir):
