@@ -48,28 +48,22 @@ def test_hocr_notlatin_warning(caplog):
     assert 'PDF renderer is known to cause' in caplog.text
 
 
-def test_old_ghostscript(caplog):
-    with patch('ocrmypdf._exec.ghostscript.version', return_value='9.19'), patch(
-        'ocrmypdf._exec.tesseract.get_languages', return_value={'eng', 'chi_sim'}
-    ):
-        vd.check_options(*make_opts_pm(language='chi_sim', output_type='pdfa'))
-        assert 'does not work correctly' in caplog.text
-
-    with patch('ocrmypdf._exec.ghostscript.version', return_value='9.18'):
-        with pytest.raises(MissingDependencyError):
-            vd.check_options(*make_opts_pm(output_type='pdfa-3'))
-
-    with patch('ocrmypdf._exec.ghostscript.version', return_value='9.24'):
-        with pytest.raises(MissingDependencyError):
-            vd.check_options(*make_opts_pm())
-
-
 def test_old_tesseract_error():
     with patch('ocrmypdf._exec.tesseract.version', return_value='4.00.00alpha'):
         with pytest.raises(MissingDependencyError):
-            opts = make_opts(pdf_renderer='sandwich', language='eng')
-            plugin_manager = get_plugin_manager(opts.plugins)
-            vd.check_options(opts, plugin_manager)
+            vd.check_options(*make_opts_pm(pdf_renderer='sandwich', language='eng'))
+
+
+def test_tesseract_not_installed(caplog):
+    with patch('ocrmypdf.subprocess.run') as not_found:
+        not_found.side_effect = FileNotFoundError('tesseract')
+        with pytest.raises(MissingDependencyError, match="Could not find program"):
+            vd.check_options(*make_opts_pm())
+            assert (
+                "'tesseract' could not be executed" in caplog.text
+            ), "Error message not printed"
+            assert 'install' in caplog.text, "Install advice not printed"
+        not_found.assert_called()
 
 
 def test_lossless_redo():
@@ -87,32 +81,12 @@ def test_mutex_options():
 
 
 def test_optimizing(caplog):
-    opts = make_opts(optimize=0, jbig2_lossy=True, png_quality=18, jpeg_quality=10)
-    plugin_manager = get_plugin_manager(opts.plugins)
-    vd.check_options(opts, plugin_manager)
+    vd.check_options(
+        *make_opts_pm(optimize=0, jbig2_lossy=True, png_quality=18, jpeg_quality=10)
+    )
     assert 'will be ignored because' in caplog.text
 
 
-def test_user_words(caplog):
-    with patch('ocrmypdf._exec.tesseract.has_user_words', return_value=False):
-        opts = make_opts(user_words='foo')
-        plugin_manager = get_plugin_manager(opts.plugins)
-        vd.check_options(opts, plugin_manager)
-        assert (
-            'Tesseract 4.0 (which you have installed) ignores --user-words'
-            in caplog.text
-        )
-    caplog.clear()
-    with patch('ocrmypdf._exec.tesseract.has_user_words', return_value=True):
-        opts = make_opts(user_patterns='foo')
-        plugin_manager = get_plugin_manager(opts.plugins)
-        vd.check_options(opts, plugin_manager)
-        assert (
-            'Tesseract 4.0 (which you have installed) ignores --user-words'
-            not in caplog.text
-        )
-
-
 def test_pillow_options():
     vd.check_options_pillow(make_opts(max_image_mpixels=0))
 
@@ -124,6 +98,8 @@ def test_output_tty():
 
 
 def test_report_file_size(tmp_path, caplog):
+    logging.getLogger('pikepdf._qpdf').setLevel(logging.CRITICAL)  # Suppress logging
+
     in_ = tmp_path / 'a.pdf'
     out = tmp_path / 'b.pdf'
     pdf = pikepdf.new()
@@ -163,10 +139,10 @@ def test_false_action_store_true():
 
 @pytest.mark.parametrize('progress_bar', [True, False])
 def test_no_progress_bar(progress_bar, resources):
-    opts = make_opts(progress_bar=progress_bar, input_file=(resources / 'trivial.pdf'))
-    plugin_manager = get_plugin_manager(opts.plugins)
-
-    vd.check_options(opts, plugin_manager)
+    opts, pm = make_opts_pm(
+        progress_bar=progress_bar, input_file=(resources / 'trivial.pdf')
+    )
+    vd.check_options(opts, pm)
 
     pbar_disabled = None
 
@@ -223,37 +199,44 @@ def test_version_comparison():
             program="tesseract",
             package="tesseract",
             version_checker=lambda: '4.0.0-beta.1',
-            need_version='4.0.0',
+            need_version='4.1.1',
             version_parser=TesseractVersion,
         )
     vd.check_external_program(
         program="tesseract",
         package="tesseract",
         version_checker=lambda: 'v5.0.0-alpha.20200201',
-        need_version='4.0.0',
+        need_version='4.1.1',
         version_parser=TesseractVersion,
     )
     vd.check_external_program(
         program="tesseract",
         package="tesseract",
         version_checker=lambda: '5.0.0-rc1.20211030',
-        need_version='4.0.0',
+        need_version='4.1.1',
         version_parser=TesseractVersion,
     )
     vd.check_external_program(
         program="tesseract",
         package="tesseract",
-        version_checker=lambda: 'v4.0.0.20181030',  # Some Windows builds use this format
-        need_version='4.0.0',
+        version_checker=lambda: 'v4.1.1.20181030',  # Some Windows builds use this format
+        need_version='4.1.1',
         version_parser=TesseractVersion,
     )
     vd.check_external_program(
-        program="tesseract",
-        package="tesseract",
-        version_checker=lambda: '4.1.1-rc2-25-g9707',
-        need_version='4.0.0',
-        version_parser=TesseractVersion,
+        program="gs",
+        package="ghostscript",
+        version_checker=lambda: '10.0',
+        need_version='9.50',
     )
+    with pytest.raises(MissingDependencyError):
+        vd.check_external_program(
+            program="tesseract",
+            package="tesseract",
+            version_checker=lambda: '4.1.1-rc2-25-g9707',
+            need_version='4.1.1',
+            version_parser=TesseractVersion,
+        )
     with pytest.raises(MissingDependencyError):
         vd.check_external_program(
             program="dummy_fails",
